@@ -1,7 +1,8 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
- *
+/*
  * Copyright (C) 2011 Colin Walters <walters@verbum.org>
  *
+ * SPDX-License-Identifier: LGPL-2.0+
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -13,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Colin Walters <walters@verbum.org>
  */
@@ -30,7 +29,8 @@ G_BEGIN_DECLS
 /**
  * OstreeDiffFlags:
  */
-typedef enum {
+typedef enum
+{
   OSTREE_DIFF_FLAGS_NONE = 0,
   OSTREE_DIFF_FLAGS_IGNORE_XATTRS = (1 << 0)
 } OstreeDiffFlags;
@@ -41,7 +41,7 @@ typedef enum {
 typedef struct _OstreeDiffItem OstreeDiffItem;
 struct _OstreeDiffItem
 {
-  volatile gint refcount;
+  gint refcount; /* atomic */
 
   GFile *src;
   GFile *target;
@@ -62,14 +62,9 @@ _OSTREE_PUBLIC
 GType ostree_diff_item_get_type (void);
 
 _OSTREE_PUBLIC
-gboolean ostree_diff_dirs (OstreeDiffFlags flags,
-                           GFile          *a,
-                           GFile          *b,
-                           GPtrArray      *modified,
-                           GPtrArray      *removed,
-                           GPtrArray      *added,
-                           GCancellable   *cancellable,
-                           GError        **error);
+gboolean ostree_diff_dirs (OstreeDiffFlags flags, GFile *a, GFile *b, GPtrArray *modified,
+                           GPtrArray *removed, GPtrArray *added, GCancellable *cancellable,
+                           GError **error);
 
 /**
  * OstreeDiffDirsOptions:
@@ -78,7 +73,8 @@ gboolean ostree_diff_dirs (OstreeDiffFlags flags,
  * that owner_uid/gid is set to -1 when not used. This is used by
  * ostree_diff_dirs_with_options().
  */
-typedef struct {
+typedef struct
+{
   gint owner_uid;
   gint owner_gid;
 
@@ -86,6 +82,7 @@ typedef struct {
 
   gboolean unused_bools[7];
   int unused_ints[6];
+  /* 4 byte hole on 64 bit */
   gpointer unused_ptrs[7];
 } OstreeDiffDirsOptions;
 
@@ -94,24 +91,19 @@ typedef struct {
  *
  * Use this to initialize an `OstreeDiffDirsOptions` structure.
  */
-#define OSTREE_DIFF_DIRS_OPTIONS_INIT { .owner_uid = -1, .owner_gid = -1, }
+#define OSTREE_DIFF_DIRS_OPTIONS_INIT \
+  { \
+    .owner_uid = -1, .owner_gid = -1, \
+  }
 
 _OSTREE_PUBLIC
-gboolean ostree_diff_dirs_with_options (OstreeDiffFlags       flags,
-                                        GFile                 *a,
-                                        GFile                 *b,
-                                        GPtrArray             *modified,
-                                        GPtrArray             *removed,
-                                        GPtrArray             *added,
-                                        OstreeDiffDirsOptions *options,
-                                        GCancellable          *cancellable,
-                                        GError                **error);
+gboolean ostree_diff_dirs_with_options (OstreeDiffFlags flags, GFile *a, GFile *b,
+                                        GPtrArray *modified, GPtrArray *removed, GPtrArray *added,
+                                        OstreeDiffDirsOptions *options, GCancellable *cancellable,
+                                        GError **error);
 
 _OSTREE_PUBLIC
-void ostree_diff_print (GFile          *a,
-                        GFile          *b,
-                        GPtrArray      *modified,
-                        GPtrArray      *removed,
-                        GPtrArray      *added);
+void ostree_diff_print (GFile *a, GFile *b, GPtrArray *modified, GPtrArray *removed,
+                        GPtrArray *added);
 
 G_END_DECLS
